#![no_std]
#![no_main]

// pick a panicking behavior
extern crate panic_halt; // you can put a breakpoint on `rust_begin_unwind` to catch panics
// extern crate panic_abort; // requires nightly
// extern crate panic_itm; // logs messages over ITM; requires ITM support
// extern crate panic_semihosting; // logs messages to the host stderr; requires a debugger

use cortex_m::{self, peripheral::syst::SystClkSource};
use cortex_m_rt::entry;
use msp432p401r as pac;
use msp432_hal::prelude::*;

use core::num::Wrapping;

const WDOG_PWORD: u8 = 0x5a;

#[entry]
fn main() -> ! {
    let cp = cortex_m::Peripherals::take().unwrap();
    let p = pac::Peripherals::take().unwrap();

    let mut syst = cp.SYST;
    let wdt = p.WDT_A;
    let dio = p.DIO;
    let pins = dio.split();

    // disable watchdog timer
    wdt.wdtctl.write(|w| unsafe {
        w.wdtpw().bits(WDOG_PWORD)
         .wdthold().wdthold_1()
    });

    // configure the system timer to wrap around every ~1 second
    syst.set_clock_source(SystClkSource::Core);
    syst.set_reload(20_000);
    syst.enable_counter();

    // Set pin 1.0 to drive the single color LED
    let mut led1 = pins.p1_0.into_strong_output();

    // Set pin 2.0-2.2 to drive the RGB LED
    let mut rgb_red = pins.p2_0.into_strong_output();
    let mut rgb_blue = pins.p2_1.into_strong_output();
    let mut rgb_green = pins.p2_2.into_strong_output();

    // Enable pull-up on P1.4 switch
    let sw2 = pins.p1_4.into_pullup();

    // Turn on LED1
    led1.set_high();

    let mut count: Wrapping<u16> = Wrapping(0);
    let mut input: u16;
    loop {
        while !syst.has_wrapped() {}

        // The button pulls the input to GND
        input = sw2.read_pin();

        count += Wrapping(1);
        let _led1: u8 = ((count.0 & 0x0100) >> 8) as u8;
        let led2: u8 = ((count.0 & 0b0000_0111_0000_0000) >> 8) as u8;

        // toggle RGB LEDs

        if led2 & 0b001 == 1 {
            rgb_red.set_high()
        } else {
            rgb_red.set_low()
        }

        if led2 & 0b010 == 1 {
            rgb_blue.set_high()
        } else {
            rgb_blue.set_low()
        }

        if led2 & 0b100 == 1 {
            rgb_green.set_high()
        } else {
            rgb_green.set_low()
        }

        // set led1 according to sw2

        if input != 0 {
            led1.set_low()
        } else {
            led1.set_high()
        }

    }
}
